@@ -1,37 +1,32 @@
 from __future__ import annotations
 
 from asyncio import TimeoutError
-from aiohttp.client_exceptions import ClientConnectorError
 from datetime import timedelta
 from json import JSONDecodeError
 from logging import getLogger
 from typing import Any, List
 
 from aiohttp import ClientSession
-
-from switchbee.const import (
-    ApiAttribute,
-    ApiCommand,
-    ApiStatus,
-)
+from aiohttp.client_exceptions import ClientConnectorError
+from switchbee.const import ApiAttribute, ApiCommand, ApiStatus
 from switchbee.device import (
     DeviceType,
     HardwareType,
+    SwitchBeeBaseDevice,
     SwitchBeeDimmer,
     SwitchBeeGroupSwitch,
     SwitchBeeRollingScenario,
     SwitchBeeScenario,
     SwitchBeeShutter,
+    SwitchBeeSomfy,
     SwitchBeeSwitch,
     SwitchBeeThermostat,
     SwitchBeeTimedSwitch,
     SwitchBeeTimerSwitch,
     SwitchBeeTwoWay,
-    SwitchBeeSomfy,
-    SwitchBeeBaseDevice,
 )
 
-from .utils import timestamp_now
+from ..utils import timestamp_now
 
 logger = getLogger(__name__)
 
@@ -289,6 +284,12 @@ class CentralUnitAPI:
                         item[ApiAttribute.NAME],
                     )
                     continue
+                except KeyError:
+                    logger.error(
+                        "device %s missing type attribute, Skipping",
+                        item[ApiAttribute.NAME],
+                    )
+                    continue
 
                 try:
                     device_hw = HardwareType(item[ApiAttribute.HARDWARE])
@@ -299,6 +300,12 @@ class CentralUnitAPI:
                         item[ApiAttribute.NAME],
                     )
                     continue
+                except KeyError:
+                    logger.error(
+                        "device %s missing hardware attribute, Skipping",
+                        item[ApiAttribute.NAME],
+                    )
+                    continue
 
                 if include and device_type not in include:
                     logger.info(
